#include "bayesiancommand.h"
#include "bayesian/bayesianestimator.h"
#include "metadata/metadatastorage.h"
#include "pipeline/single_illuminant_pipeline.h"
#include <opencv2/highgui/highgui.hpp>

namespace illumestimators {

BayesianCommand::BayesianCommand():
	Command("bayesian",
		config,
		"Michael Bleier",
		"michael.bleier@mb.stud.uni-erlangen.de"
	)
{
}

int BayesianCommand::execute()
{
	BayesianEstimator estimator((illumestimators::BayesianEstimator::Method) config.method);

	MetadataStorage storage(config.metaFiles);

	if (!SingleIlluminantPipeline::loadIlluminantEstimator(estimator, config.loadFile)) {
		if (!SingleIlluminantPipeline::runTraining(estimator, config.trainingFiles, storage, config.verbosity)) {
			std::cerr << "Error no training data and no classifier loaded. Aborted." << std::endl;
			return 1;
		}
	}
	SingleIlluminantPipeline::saveIlluminantEstimator(estimator, config.saveFile);

	Illum estimate;
	double error;

	if (config.inputFile.length() > 0) {
		if (!SingleIlluminantPipeline::runEstimator(estimate, error, estimator, config.inputFile, storage, config.verbosity)) {
			return -1;
		}
	}

	return 0;
}

void BayesianCommand::printShortHelp() const
{
	std::cout << "Bayesian illuminant estimator." << std::endl;
}

void BayesianCommand::printHelp() const
{
	std::cout << "Bayesian illuminant estimator." << std::endl;
}

} // namespace illumestimators
