#include "commands/create_per_segment_estimates_config.h"

using namespace boost::program_options;

namespace illumestimators {

CreatePerSegmentEstimatesConfig::CreatePerSegmentEstimatesConfig(const std::string& prefix) :
	Config(prefix)
{
	#ifdef WITH_BOOST
		initBoostOptions();
	#endif // WITH_BOOST
}

std::string CreatePerSegmentEstimatesConfig::getString() const
{
	std::stringstream s;

	if (prefix_enabled) {
		s << "[" << prefix << "]" << std::endl;
	} else {
		s	<< "input=" << inputFile << " # input list file" << std::endl
			<< "output=" << output_path << " # Working directory" << std::endl;
	}
	s	<< "gamut2d=" << gamut2d_1s_file << " # trained 2d gamut mapper" << std::endl
		<< "gamut3d=" << gamut3d_1s_file << " # trained 3d gamut mapper" << std::endl
		<< "bayesian=" << bayesian_el_file << " # trained bayesian histogram" << std::endl
		<< "onlyGW=" << (onlyGW ? 1 : 0) << " # operate only with gray world algorithms" << std::endl
		<< "load=" << loadFile << " # Load illuminant estimator from file" << std::endl
		<< "save=" << saveFile << " # Save illuminant estimator to file" << std::endl
	;

	return s.str();
}

#ifdef WITH_BOOST
void CreatePerSegmentEstimatesConfig::initBoostOptions()
{
	if (!prefix_enabled) {
		options.add_options()
			(key("input,I"), value(&inputFile)->default_value(""), "input list file")
			(key("output,O"), value(&output_path)->default_value(""), "Working directory")

			(key("gamut2d,G"), value(&gamut2d_1s_file)->default_value(""), "trained 2d gamut mapper")
			(key("gamut3d,F"), value(&gamut3d_1s_file)->default_value(""), "trained 3d gamut mapper")
			(key("bayesian,B"), value(&bayesian_el_file)->default_value(""), "trained bayesian histogram")
			(key("onlyGW,g"), bool_switch(&onlyGW)->default_value(false), "operate only with gray world algorithms")

//			(key("train,T"), boost::program_options::value(&trainingFiles)->multitoken(), "List of training files")

			(key("load,l"), boost::program_options::value(&loadFile)->default_value(""), "Load illuminant estimator from file")
			(key("save,s"), boost::program_options::value(&saveFile)->default_value(""), "Save illuminant estimator to file")
		;
	}
}
#endif // WITH_BOOST

} // namespace illumestimators
