#ifndef ILLUMESTIMATORS_FUSION_BOOSTING_GRADIENTBOOSTINGFUSION_H
#define ILLUMESTIMATORS_FUSION_BOOSTING_GRADIENTBOOSTINGFUSION_H

#include "fusion/fusion.h"
#include <opencv2/ml/ml.hpp>

namespace illumestimators {

class GradientBoostingFusion : public Fusion
{
public:
	GradientBoostingFusion();
	GradientBoostingFusion(const std::vector<IlluminantEstimator*>& estimators);
	~GradientBoostingFusion();

public:
	std::string name() const;
	std::string identifier() const;

public:
	using IlluminantEstimator::estimateIlluminant;
	Illum estimateIlluminant(const cv::Mat_<cv::Vec3d>& image, const cv::Mat_<unsigned char>& mask) const;
	Illum estimateIlluminant(const cv::Mat_<cv::Vec3d>& image, const std::vector<cv::Point>& superpixel, const cv::Mat_<unsigned char>& mask) const;
	Illum estimateIlluminant(const std::vector<cv::Vec3d>& estimates) const;

public:
	bool train(const std::vector<std::string>& imageFiles, const std::vector<std::string>& colorspaces, const std::vector<cv::Vec3d>& illuminants, const std::vector<std::string>& maskFiles = std::vector<std::string>());
	bool train(const std::vector<std::vector<cv::Vec3d> >& estimates, const std::vector<cv::Vec3d>& illuminants);

	virtual void preprocessImage(const cv::Mat_<cv::Vec3d>& image, const cv::Mat_<unsigned char>& mask, cv::Mat_<cv::Vec3d> &outputImage, cv::Mat_<unsigned char> &outputMask) const;

public:
	bool save(const std::string& filename) const;
	bool load(const std::string& filename);
	virtual int error(); // dummy implementation - returns always 0

private:
	CvGBTrees m_trees[3];
};

} // namespace illumestimators

#endif // ILLUMESTIMATORS_FUSION_BOOSTING_GRADIENTBOOSTINGFUSION_H
